@@ -14,11 +14,8 @@
 #'   units.
 #' @param alpha numeric, probability of a type 1 error, so confidence
 #'   coefficient = 1-alpha
+#' @param na.pad logical. If `na.pad = TRUE` incomplete windows (duration of the window < `n`) return `NA`. Defatuls to `TRUE`
 #'
-#' @import dplyr
-#' @import rlang
-#' @importFrom purrr map
-#' @importFrom tidyr unnest
 #' @return tibble with binomial point estimate and confidence intervals.
 #' @export
 #' @seealso \code{\link{binom_ci}}
@@ -32,20 +29,21 @@
 #' ## Run Function
 #' tbr_binom(df, x = value,
 #' tcolumn = date, unit = "years", n = 5,
-#' alpha = 0.1)
-tbr_binom <- function(.tbl, x, tcolumn, unit = "years", n, alpha = 0.05) {
+#' alpha = 0.1, na.pad = FALSE)
+tbr_binom <- function(.tbl, x, tcolumn, unit = "years", n, alpha = 0.05, na.pad = TRUE) {
 
   .tbl <- .tbl %>%
-    arrange(!! rlang::enquo(tcolumn)) %>%
-    mutate("temp" := purrr::map(row_number(),
-                                  ~tbr_binom_window(x = !! rlang::enquo(x), #column that indicates success/failure
-                                               tcolumn = !! rlang::enquo(tcolumn), #posix formatted time column
+    arrange(!! enquo(tcolumn)) %>%
+    mutate("temp" := map(row_number(),
+                                  ~tbr_binom_window(x = !! enquo(x), #column that indicates success/failure
+                                               tcolumn = !! enquo(tcolumn), #posix formatted time column
                                                unit = unit,
                                                n = n,
                                                alpha = alpha,
-                                               i = .x))) %>%
-    tidyr::unnest("temp")
-  .tbl <- tibble::as_tibble(.tbl)
+                                               i = .x,
+                                               na.pad = na.pad))) %>%
+    unnest("temp")
+  .tbl <- as_tibble(.tbl)
   return(.tbl)
 }
 
@@ -60,10 +58,11 @@ tbr_binom <- function(.tbl, x, tcolumn, unit = "years", n, alpha = 0.05) {
 #' @param i rows
 #' @param alpha numeric, probability of a type 1 error, so confidence
 #'   coefficient = 1-alpha
+#' @param na.pad logical. If `na.pad = TRUE` incomplete windows (duration of the window < `n`) return `NA`.
 #'
 #' @return list
 #' @keywords internal
-tbr_binom_window <- function(x, tcolumn, unit = "years", n, i, alpha) {
+tbr_binom_window <- function(x, tcolumn, unit = "years", n, i, alpha, na.pad) {
 
   # checks for valid unit values
   u <- (c("years", "months", "weeks", "days", "hours", "minutes", "seconds"))
@@ -73,7 +72,7 @@ tbr_binom_window <- function(x, tcolumn, unit = "years", n, i, alpha) {
   }
 
   # creates a time-based window
-  window <- open_window(x, tcolumn, unit = unit, n, i)
+  window <- open_window(x, tcolumn, unit = unit, n, i, na.pad)
   df <- tibble(window) %>%
     summarise(n = n(), successes = as.integer(sum(window)))
 
@@ -123,7 +122,6 @@ tbr_binom_window <- function(x, tcolumn, unit = "years", n, i, alpha) {
 #' @param return.df logical flag to indicate that a data frame rather than a
 #'   matrix be returned.
 #'
-#' @importFrom stats qf qnorm
 #' @export
 #' @author Frank Harrell, modified by Michael Schramm
 #' @keywords internal
@@ -143,6 +141,18 @@ binom_ci <- function(x, n, alpha = 0.05,
                      method = c("wilson","exact","asymptotic"),
                      return.df = FALSE)
 {
+  
+  if (is.na(x)) {
+    mat <- matrix(ncol = 3, nrow = length(1))
+    dimnames(mat) <- list(rep("", dim(mat)[1]),
+                          c("PointEst", "Lower", "Upper"))
+    if (return.df) {
+      mat <- as.data.frame(mat, row.names = NULL)
+      return(mat)
+    } else  {
+      return(mat)
+    }
+  }
   ## ..modifications for printing and the addition of a
   ##   method argument and the asymptotic interval
   ##   and to accept vector arguments were
@@ -153,6 +163,7 @@ binom_ci <- function(x, n, alpha = 0.05,
   {
     nu1 <- 2 * (n - x + 1)
     nu2 <- 2 * x
+
     ll <- if (x > 0)
       x/(x + qf(1 - alpha/2, nu1, nu2) * (n - x + 1))
     else
