@@ -7,6 +7,7 @@
 #' @param tcolumn formatted time column.
 #' @param unit character, one of "years", "months", "weeks", "days", "hours", "minutes", "seconds"
 #' @param n numeric, describing the length of the time window.
+#' @param na.pad logical. If `na.pad = TRUE` incomplete windows (duration of the window < `n`) return `NA`. Defaults to `TRUE`
 #' @param ... additional arguments passed to \code{\link{median_ci}}
 #'
 #' @import rlang
@@ -18,12 +19,12 @@
 #' @examples
 #' ## Return a tibble with new rolling median column
 #' tbr_median(Dissolved_Oxygen, x = Average_DO, tcolumn = Date, unit = "years",
-#' n = 5)
+#' n = 5, na.pad = FALSE)
 #' 
 #' \dontrun{
 #' ## Return a tibble with rolling median and 95% CI 
 #' tbr_median(Dissolved_Oxygen, x = Average_DO, tcolumn = Date, unit = "years", n = 5, conf = .95)}
-tbr_median <- function(.tbl, x, tcolumn, unit = "years", n, ...) {
+tbr_median <- function(.tbl, x, tcolumn, unit = "years", n, na.pad = TRUE, ...) {
 
   dots <- list(...)
 
@@ -46,6 +47,7 @@ tbr_median <- function(.tbl, x, tcolumn, unit = "years", n, ...) {
                                         unit = unit,
                                         n = n,
                                         i = .x,
+                                        na.pad = na.pad,
                                         conf = default_dots$conf,
                                         na.rm = default_dots$na.rm,
                                         type = default_dots$type,
@@ -65,13 +67,14 @@ tbr_median <- function(.tbl, x, tcolumn, unit = "years", n, ...) {
 #' @param unit character, one of "years", "months", "weeks", "days", "hours", "minutes", "seconds"
 #' @param n numeric, describing the length of the time window.
 #' @param i row
+#' @param na.pad logical. If `na.pad = TRUE` incomplete windows (duration of the window < `n`) return `NA`. 
 #' @param ... additional arguments passed to \code{\link{median_ci}}
 #'
 #' @importFrom lubridate as.duration duration
 #' @importFrom tibble as.tibble
 #' @return list
 #' @keywords internal
-tbr_median_window <- function(x, tcolumn, unit = "years", n, i, ...) {
+tbr_median_window <- function(x, tcolumn, unit = "years", n, i, na.pad, ...) {
 
   # checks for valid unit values
   u <- (c("years", "months", "weeks", "days", "hours", "minutes", "seconds"))
@@ -91,7 +94,7 @@ tbr_median_window <- function(x, tcolumn, unit = "years", n, i, ...) {
   else {
     # create a time-based window by calculating the duration between current row
     # and the previous rows select the rows where 0 <= duration <= n
-    window <- open_window(x, tcolumn, unit = unit, n, i)
+    window <- open_window(x, tcolumn, unit = unit, n = n, i = i, na.pad = na.pad)
 
     # if length is 1 or less, return NAs
     if (length(window) <= 1) {
@@ -130,9 +133,6 @@ tbr_median_window <- function(x, tcolumn, unit = "years", n, i, ...) {
 #'
 #' @return named list with mean and (optionally) specified confidence
 #'   interval
-#' @import boot
-#' @importFrom stats var
-#' @importFrom stats median
 #' @export
 #'
 #' @keywords internal
